@@ -7,6 +7,9 @@ from vatis.asr_commons.domain import AudioFormatError
 class Language(Enum):
     ro_RO = 'ro_RO'
     en_GB = 'en_GB'
+    de_DE = 'de_DE'
+    es_ES = 'es_ES'
+    fr_FE = 'fr_FR'
 
 
 class SampleRate(Enum):
