@@ -135,17 +135,36 @@ def parse_hotwords_config(headers) -> Dict[str, Any]:
 
 
 def parse_formatting_config(headers) -> Dict[str, Any]:
+    from vatis.asr_commons.domain import SpokenCommandConfig
+    from vatis.asr_commons.domain import FindReplaceConfig
+
     config: Dict[str, Any] = {}
 
     if COMMANDS_EXPRESSIONS_HEADER in headers:
-        command_configs = json.loads(headers[COMMANDS_EXPRESSIONS_HEADER])
+        command_configs: list = json.loads(headers[COMMANDS_EXPRESSIONS_HEADER])
+
+        if isinstance(command_configs, dict):
+            command_configs = [SpokenCommandConfig.from_json(command_configs)]
+        elif isinstance(command_configs, list):
+            command_configs = [SpokenCommandConfig.from_json(config) for config in command_configs]
+        else:
+            logger.warning(f'Spoken commands not parsable: {str(headers[COMMANDS_EXPRESSIONS_HEADER])}')
+
         config[TranscriptionOptions.COMMANDS_EXPRESSIONS] = command_configs
 
     if ENABLE_ON_COMMAND_FINAL_FRAME_HEADER in headers:
         config[TranscriptionOptions.ENABLE_ON_COMMAND_FINAL_FRAME] = str(headers[ENABLE_ON_COMMAND_FINAL_FRAME_HEADER]).lower() == 'true'
 
     if FIND_REPLACE_EXPRESSIONS_HEADER in headers:
-        find_replace_configs = json.loads(headers[FIND_REPLACE_EXPRESSIONS_HEADER])
+        find_replace_configs: list = json.loads(headers[FIND_REPLACE_EXPRESSIONS_HEADER])
+
+        if isinstance(find_replace_configs, dict):
+            find_replace_configs = [FindReplaceConfig.from_json(find_replace_configs)]
+        elif isinstance(find_replace_configs, list):
+            find_replace_configs = [FindReplaceConfig.from_json(config) for config in find_replace_configs]
+        else:
+            logger.warning(f'find replace not parsable: {str(headers[FIND_REPLACE_EXPRESSIONS_HEADER])}')
+
         config[TranscriptionOptions.FIND_REPLACE_EXPRESSIONS] = find_replace_configs
 
     return config
