@@ -20,20 +20,34 @@ DEFAULT_REPLACEMENT_MERGE: str = ReplacementMerge.STANDALONE
 DEFAULT_REPLACEMENT_ENTITY: str = Word.Entity.REPLACED
 
 
-@dataclasses.dataclass(frozen=True)
 class FindReplaceConfig(JSONDeserializable):
-    replacement: str
-    regex: List[str]
-    enabled: bool = True
-    merge: str = DEFAULT_REPLACEMENT_MERGE
-    entity: str = DEFAULT_REPLACEMENT_ENTITY
+    def __init__(self,
+                 replacement: str,
+                 regex: List[str],
+                 merge: str = DEFAULT_REPLACEMENT_MERGE,
+                 entity: str = DEFAULT_REPLACEMENT_ENTITY,
+                 enabledOnPrerecordedFiles: bool = True,
+                 enabledOnLiveTranscription: bool = True,
+                 **kwargs):
+        self.replacement: str = replacement
+        self.regex: List[str] = regex
+        self.merge: str = merge
+        self.entity: str = entity
+        self.enabledOnPrerecordedFiles: bool = enabledOnPrerecordedFiles
+        self.enabledOnLiveTranscription: bool = enabledOnLiveTranscription
 
-    def __post_init__(self):
         assert self.replacement is not None, '"replacement" must not be none'
         assert self.regex is not None, '"regex" must not be none'
-        assert self.enabled is not None, '"enabled" must not be none'
         assert self.merge is not None, '"merge" must not be none'
         assert self.entity is not None, '"entity" must not be none'
+        assert self.enabledOnPrerecordedFiles is not None, '"enabledOnPrerecordedFiles" must not be none'
+        assert self.enabledOnLiveTranscription is not None, '"enabledOnLiveTranscription" must not be none'
+
+        # backwards compatibility
+        if 'enabled' in kwargs and isinstance(kwargs['enabled'], bool):
+            enabled = kwargs['enabled']
+            self.enabledOnPrerecordedFiles = enabled
+            self.enabledOnLiveTranscription = enabled
 
     @staticmethod
     def from_json(json_dict: dict):
@@ -69,7 +83,7 @@ class FindReplaceExpressions(Expressions):
         return self._replacement_merge.get(key, DEFAULT_REPLACEMENT_MERGE)
 
     def get_replacement_entity(self, key: str) -> str:
-        return self._replacement_merge.get(key, DEFAULT_REPLACEMENT_ENTITY)
+        return self._replacement_entity.get(key, DEFAULT_REPLACEMENT_ENTITY)
 
     @staticmethod
     def from_find_replace_config_list(expressions: List[Union[FindReplaceConfig, dict]]) -> 'FindReplaceExpressions':
@@ -104,30 +118,33 @@ class FindReplaceExpressions(Expressions):
             try:
                 line = line.strip()
 
-                if line.startswith('#'):
+                if line.startswith('#') or not len(line):
                     continue
 
                 tokens = line.split('\t')
-                merge = tokens[0]
-                entity = tokens[1]
-                key = tokens[2]
-                regex = tokens[3:]
+
+                token_idx: int = 0
+
+                if tokens[token_idx] in ReplacementMerge.__dict__:
+                    merge = tokens[token_idx]
+                    token_idx += 1
+                else:
+                    merge = DEFAULT_REPLACEMENT_MERGE
+
+                if tokens[token_idx] in Word.Entity.__dict__:
+                    entity = tokens[token_idx]
+                    token_idx += 1
+                else:
+                    entity = DEFAULT_REPLACEMENT_ENTITY
+
+                key = tokens[token_idx]
+                token_idx += 1
+
+                regex = tokens[token_idx:]
 
                 if not len(regex):
                     continue
 
-                if merge not in ReplacementMerge.__dict__:
-                    if fail_on_error:
-                        raise ValueError(f'Bad merge option: {merge}')
-                    else:
-                        merge = DEFAULT_REPLACEMENT_MERGE
-
-                if entity not in Word.Entity.__dict__:
-                    if fail_on_error:
-                        raise ValueError(f'Bad entity option: {entity}')
-                    else:
-                        entity = DEFAULT_REPLACEMENT_ENTITY
-
                 expressions[key] = regex
                 replacement_merge[key] = merge
                 replacement_entity[key] = entity
